CSVFILE = """\
route_id,route_short_name,route_long_name,route_desc,route_type,route_url,route_color,route_text_color
2,1,"GARE DE L'OUEST - STOCKEL",,1,,C4008F,FFFFFF
3,2,"SIMONIS - ELISABETH",,1,,F57000,FFFFFF
5,3,"ESPLANADE - CHURCHILL",,0,,B5BA05,000000
8,4,"GARE DU NORD - STALLE (P)",,0,,F25482,000000
1,5,"ERASME - HERRMANN-DEBROUX",,1,,E6B012,FFFFFF
4,6,"ROI BAUDOUIN - ELISABETH",,1,,0078AD,FFFFFF
6,7,"VANDERKINDERE - HEYSEL",,0,,FFF06E,000000
11,8,"LOUISE - ROODEBEEK",,0,,00A1DF,000000
12,9,"SIMONIS - ARBRE BALLON",,0,,FF00FF,FFFFFF
71,12,"BRUSSELS AIRPORT - BRUSSELS CITY",,3,,338C26,FFFFFF
23,13,"SIMONIS - UZ-VUB",,3,,9EBFE3,000000
24,14,"GARE DU NORD - UZ-VUB",,3,,FF9EC2,000000
46,17,"BEAULIEU - HEILIGENBORRE",,3,,DE3B21,FFFFFF
13,19,"GROOT-BIJGAARDEN - DE WAND",,0,,DE3B21,FFFFFF
25,20,"HUNDERENVELD - GARE DU NORD",,3,,E3BA12,000000
70,21,"BRUSSELS AIRPORT - LUXEMBOURG",,3,,F7E017,000000
16,25,"BOONDAEL GARE - ROGIER",,0,,991F36,FFFFFF
47,27,"GARE DU MIDI - ANDROMEDE",,3,,9EBFE3,000000
48,28,"BRABANCONNE - KONKEL",,3,,DE3B21,FFFFFF
72,29,"DE BROUCKERE - HOF TEN BERG",,3,,E87D0D,FFFFFF
22,32,"DA VINCI - DROGENBOS CHATEAU",,0,,F7E017,000000
27,33,"DANSAERT - LOUISE",,3,,FF9EC2,000000
49,34,"PORTE DE NAMUR - SAINTE-ANNE",,3,,E3BA12,000000
50,36,"SCHUMAN - KONKEL",,3,,9EBFE3,000000
28,37,"ALBERT - GARE DE LINKEBEEK",,3,,36578C,FFFFFF
51,38,"GARE CENTRALE - HEROS",,3,,B085B3,FFFFFF
19,39,"MONTGOMERY - BAN-EIK",,0,,DE3B21,FFFFFF
52,41,"HEROS - TRANSVAAL",,3,,9EBFE3,000000
64,42,"VIADUC E40 - ROODEBEEK",,3,,338C26,FFFFFF
29,43,"OBSERVATOIRE - VIVIER D'OIE",,3,,996308,FFFFFF
18,44,"MONTGOMERY - TERVUREN STATION",,0,,E3BA12,000000
65,45,"ROODEBEEK - SAINT-VINCENT",,3,,B085B3,FFFFFF
30,46,"MOORTEBEEK - ANNEESSENS",,3,,DE3B21,FFFFFF
66,47,"DE BROUCKERE - VILVOORDE STATION",,3,,B085B3,FFFFFF
84,48,"GRAND-PLACE - DECROLY",,3,,338C26,FFFFFF
32,49,"GARE DU MIDI - BOCKSTAEL",,3,,36578C,FFFFFF
33,50,"GARE DU MIDI - LOT STATION",,3,,B5BA05,000000
14,51,"STADE - VAN HAELEN",,0,,E3BA12,000000
76,53,"HOPITAL MILITAIRE - UZ-VUB",,3,,338C26,FFFFFF
34,54,"TRONE - FOREST (BERVOETS)",,3,,DE3B21,FFFFFF
17,55,"DA VINCI - ROGIER",,0,,E3BA12,000000
75,57,"GARE DU NORD - HOPITAL MILITAIRE",,3,,DE3B21,FFFFFF
67,58,"VILVOORDE STATION - YSER",,3,,338C26,FFFFFF
68,59,"HOPITAL ETTERBEEK-IXELLES - BORDET STATION",,3,,996308,FFFFFF
53,60,"AMBIORIX - UCCLE CALEVOET",,3,,FF9EC2,000000
54,61,"GARE DU NORD - MONTGOMERY",,3,,F7E017,000000
7,62,"EUROCONTROL - CIMETIERE DE JETTE",,0,,FF9EC2,000000
77,63,"GARE CENTRALE - CIMETIERE DE BRUXELLES",,3,,9EBFE3,000000
79,64,"PORTE DE NAMUR - MACHELEN",,3,,DE3B21,FFFFFF
78,65,"GARE CENTRALE - BOURGET",,3,,E3BA12,000000
73,66,"DE BROUCKERE - PEAGE",,3,,36578C,FFFFFF
74,69,"SCHAERBEEK GARE - JULES BORDET",,3,,E87D0D,FFFFFF
55,71,"DE BROUCKERE - DELTA",,3,,338C26,FFFFFF
56,72,"ULB - ADEPS",,3,,FF9EC2,000000
35,75,"CAMPUS CERIA - BON AIR",,3,,F7E017,000000
57,76,"KRAAINEM - OPPEM",,3,,F7E017,000000
58,77,"KRAAINEM - HIPPODROME",,3,,338C26,FFFFFF
85,78,"HUMANITE - GARE DU MIDI",,3,,B085B3,FFFFFF
69,79,"KRAAINEM - SCHUMAN",,3,,36578C,FFFFFF
59,80,"PORTE DE NAMUR - MAES",,3,,338C26,FFFFFF
20,81,"MARIUS RENARD - MONTGOMERY",,0,,338C26,FFFFFF
15,82,"BERCHEM STATION - DROGENBOS CHATEAU",,0,,9EBFE3,000000
37,84,"BERCHEM STATION - HEYSEL",,3,,F7E017,000000
38,86,"MACHTENS - GARE CENTRALE",,3,,338C26,FFFFFF
26,87,"SIMONIS - BEEKKANT",,3,,338C26,FFFFFF
39,88,"DE BROUCKERE - HEYSEL",,3,,991F36,FFFFFF
31,89,"WESTLAND SHOPPING - BOCKSTAEL",,3,,E87D0D,FFFFFF
9,92,"SCHAERBEEK GARE - FORT-JACO",,0,,DE3B21,FFFFFF
21,93,"STADE - LEGRAND",,0,,E87D0D,FFFFFF
60,95,"GRAND-PLACE - WIENER",,3,,36578C,FFFFFF
10,97,"LOUISE - DIEWEG",,0,,991F36,FFFFFF
36,98,"CERIA - HEROS",,3,,FC8306,FFFFFF
45,T32,"DA VINCI - DROGENBOS CHATEAU",,3,,F7E017,000000
83,T55,"DA VINCI - ROGIER",,3,,E3BA12,000000
86,T81,"MARIUS RENARD - MONTGOMERY",,3,,338C26,FFFFFF
44,T82,"BERCHEM STATION - DROGENBOS CHATEAU",,3,,9EBFE3,000000
63,T92,"SCHAERBEEK GARE - FORT-JACO",,3,,DE3B21,FFFFFF
81,N04,"GARE CENTRALE - CIMETIERE DE BRUXELLES",,3,,FF00FF,FFFFFF
82,N05,"GARE CENTRALE - KRAAINEM",,3,,9978B8,FFFFFF
80,N06,"GARE CENTRALE - MUSEE DU TRAM",,3,,00C8FF,FFFFFF
61,N08,"GARE CENTRALE - WIENER",,3,,94C9FD,000000
62,N09,"GARE CENTRALE - HERRMANN-DEBROUX",,3,,FF00FF,FFFFFF
40,N10,"GARE CENTRALE - FORT-JACO",,3,,D2FF0A,000000
87,N11,"GARE CENTRALE - HOMBORCH",,3,,976A0E,FFFFFF
42,N12,"GARE CENTRALE - CARREFOUR STALLE",,3,,FC8306,FFFFFF
88,N13,"GARE CENTRALE - WESTLAND SHOPPING",,3,,C30C3E,FFFFFF
43,N16,"GARE CENTRALE - BERCHEM STATION",,3,,0A3C0A,FFFFFF
41,N18,"GARE CENTRALE - HEYSEL",,3,,64D214,FFFFFF
"""
